@@ -1,7 +1,7 @@
 package Sah::Schemas::Float;
 
 our $DATE = '2020-06-04'; # DATE
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 1;
 # ABSTRACT: Sah schemas for various floating types
@@ -18,7 +18,7 @@ Sah::Schemas::Float - Sah schemas for various floating types
 
 =head1 VERSION
 
-This document describes version 0.010 of Sah::Schemas::Float (from Perl distribution Sah-Schemas-Float), released on 2020-06-04.
+This document describes version 0.011 of Sah::Schemas::Float (from Perl distribution Sah-Schemas-Float), released on 2020-06-04.
 
 =head1 SAH SCHEMAS
 
@@ -28,6 +28,10 @@ This document describes version 0.010 of Sah::Schemas::Float (from Perl distribu
 
 Inf or -Inf.
 
+=item * L<int_or_inf|Sah::Schema::int_or_inf>
+
+Integer, or InfE<sol>-Inf.
+
 =item * L<nan|Sah::Schema::nan>
 
 NaN.
@@ -65,6 +69,14 @@ See also C<ufloat> for floats that are equal or larger than 0.
 
 Inf but not -Inf.
 
+=item * L<posint_or_posinf|Sah::Schema::posint_or_posinf>
+
+Positive integer, or Inf.
+
+Can be used to check value for number of items in a (possibly infinite)
+sequence.
+
+
 =item * L<share|Sah::Schema::share>
 
 A float between 0 and 1.
@@ -87,6 +99,14 @@ Non-negative float.
 See also C<posfloat> for floats that are larger than 0.
 
 
+=item * L<uint_or_posinf|Sah::Schema::uint_or_posinf>
+
+Unsigned integer, or Inf.
+
+Can be used to check value for number of items in a (possibly infinite)
+sequence.
+
+
 =back
 
 =head1 HOMEPAGE
